#[macro_use]
extern crate log;

extern crate byteorder;
extern crate crossbeam_channel;
extern crate ommui_broadcast;
extern crate serialport;
extern crate snafu;
extern crate try_from;
extern crate uuid;
extern crate xio_base_datatypes;

use byteorder::LittleEndian as Endian;
use try_from::{TryFrom, TryInto};

use xio_base_datatypes as base;

mod error;
pub use crate::error::Error;

mod connection;
pub use crate::connection::{
    Connection, NotificationItem, ResponseItem, SendAndReceive,
};

mod data_type;
use crate::data_type::{DataTypeReaderExt, DataTypeWriterExt};

mod data_value;
use crate::data_value::{DataValueReaderExt, DataValueWriterExt};

mod device_capability;
pub use crate::device_capability::DeviceCapability;
use crate::device_capability::DeviceCapabilityReaderExt;

mod error_code;
use crate::error_code::{ErrorCodeReaderExt, ErrorCodeWriterExt};

mod io_helper;
pub(crate) use crate::io_helper::{ReadExt, WriteExt};

mod job_set_info;
pub use crate::job_set_info::JobSetInfo;
use crate::job_set_info::JobSetInfoReaderExt;

mod job_stopped_reason;
use crate::job_stopped_reason::{
    JobStoppedReasonReaderExt, JobStoppedReasonWriterExt,
};

mod messages;
pub use crate::messages::*;

mod module_state;
use crate::module_state::{ModuleStateReaderExt, ModuleStateWriterExt};

mod parameter_value;
use crate::parameter_value::{
    ParameterValueReaderExt, ParameterValueWriteMode,
    ParameterValueWriterExt,
};

mod with_fixed_payload_length;
pub(crate) use crate::with_fixed_payload_length::WithFixedPayloadLength;

pub type Result<T> = std::result::Result<T, Error>;
